==> kmail-22.12.0.tar.xz: kmail-22.12.0/src/kontactplugin/kmail/kmailplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "Kontact KMail Plugin",
        "Description[ar]": "ملحقة «بريدك» لِ‍«متراسلك»",
        "Description[az]": "Kontact KMail plaqini",
        "Description[bg]": "Приставка за контакти на KMail",
        "Description[ca@valencia]": "Connector de KMail de Kontact",
        "Description[ca]": "Connector del KMail del Kontact",
        "Description[cs]": "Modul KMailu pro aplikaci Kontact",
        "Description[de]": "KMail-Modul für Kontact",
        "Description[en_GB]": "Kontact KMail Plugin",
        "Description[es]": "Complemento de KMail para Kontact",
        "Description[eu]": "Kontact-erako KMail-en plugina",
        "Description[fi]": "Kontactin KMail-liitännäinen",
        "Description[fr]": "Module externe « KMail » pour Kontact",
        "Description[ia]": "Plug-in pro Kontact KMail",
        "Description[id]": "Plugin Kontact KMail",
        "Description[it]": "Estensione per Kontact di KMail",
        "Description[ka]": "Kontact-ის დამატება KMail -სთვის",
        "Description[ko]": "Kontact KMail 플러그인",
        "Description[nl]": "Kontact KMail-plug-in",
        "Description[pl]": "Wtyczka Kontact do współpracy z KMail",
        "Description[pt]": "'Plugin' do KMail para o Kontact",
        "Description[pt_BR]": "Plugin do KMail para o Kontact",
        "Description[ru]": "Почта",
        "Description[sl]": "Vstavek Kontact za KMail",
        "Description[sv]": "Kontact-insticksprogram för Kmail",
        "Description[ta]": "காண்டாக்டுக்கான கேமெயில் செருகுநிரல்",
        "Description[tr]": "Kontact KMail Eklentisi",
        "Description[uk]": "Додаток електронної пошти Kontact",
        "Description[x-test]": "xxKontact KMail Pluginxx",
        "Description[zh_CN]": "Kontact KMail 插件",
        "EnabledByDefault": true,
        "Icon": "view-pim-mail",
        "Id": "kontact_kmailplugin",
        "License": "GPL",
        "Name": "Mail",
        "Name[af]": "Pos",
        "Name[ar]": "البريد",
        "Name[az]": "Poçt",
        "Name[be]": "Пошта",
        "Name[bg]": "Mail",
        "Name[br]": "Lizher",
        "Name[bs]": "Elektronska pošta",
        "Name[ca@valencia]": "Correu",
        "Name[ca]": "Correu",
        "Name[cs]": "Pošta",
        "Name[cy]": "Ebost",
        "Name[da]": "E-mail",
        "Name[de]": "E-Mail",
        "Name[el]": "Αλληλογραφία",
        "Name[en_GB]": "Mail",
        "Name[eo]": "Retpoŝto",
        "Name[es]": "Correo",
        "Name[et]": "E-post",
        "Name[eu]": "Posta",
        "Name[fa]": "نامه",
        "Name[fi]": "Sähköposti",
        "Name[fr]": "Messages",
        "Name[fy]": "E-post",
        "Name[ga]": "Ríomhphost",
        "Name[gl]": "Correo electrónico",
        "Name[he]": "דוא\"ל",
        "Name[hr]": "Pošta",
        "Name[hu]": "E-mail",
        "Name[ia]": "Posta",
        "Name[id]": "Mail",
        "Name[is]": "Póstur",
        "Name[it]": "Posta",
        "Name[ja]": "メール",
        "Name[ka]": "წერილი",
        "Name[kk]": "Пошта",
        "Name[km]": "សំបុត្រ",
        "Name[ko]": "이메일",
        "Name[lt]": "Paštas",
        "Name[lv]": "Pasts",
        "Name[mai]": "डाक",
        "Name[mk]": "Е-пошта",
        "Name[mr]": "मेल",
        "Name[ms]": "Mel",
        "Name[nb]": "E-post",
        "Name[nds]": "Nettpost",
        "Name[ne]": "पत्र",
        "Name[nl]": "E-mail",
        "Name[nn]": "E-post",
        "Name[pa]": "ਮੇਲ",
        "Name[pl]": "Poczta",
        "Name[pt]": "E-mail",
        "Name[pt_BR]": "E-mail",
        "Name[ro]": "Poștă",
        "Name[ru]": "Почта",
        "Name[se]": "E-boasta",
        "Name[sk]": "Pošta",
        "Name[sl]": "Pošta",
        "Name[sr@ijekavian]": "Пошта",
        "Name[sr@ijekavianlatin]": "Pošta",
        "Name[sr@latin]": "Pošta",
        "Name[sr]": "Пошта",
        "Name[sv]": "Brev",
        "Name[ta]": "அஞ்சல்",
        "Name[tg]": "Мактуб",
        "Name[th]": "จดหมาย",
        "Name[tr]": "E-Posta",
        "Name[ug]": "خەت",
        "Name[uk]": "Пошта",
        "Name[uz@cyrillic]": "Хат-хабар",
        "Name[uz]": "Xat-xabar",
        "Name[wa]": "Emile",
        "Name[x-test]": "xxMailxx",
        "Name[zh_CN]": "邮寄",
        "Name[zh_TW]": "郵件",
        "Version": "0.1",
        "Website": "https://kontact.kde.org/components/kmail/"
    },
    "X-KDE-ConfigModuleNamespace": "pim@QT_MAJOR_VERSION@/kcms/kmail/",
    "X-KDE-KontactPartExecutableName": "kmail",
    "X-KDE-KontactPartLibraryName": "kmailpart",
    "X-KDE-KontactPartLoadOnStart": true,
    "X-KDE-KontactPluginHasSummary": true,
    "X-KDE-KontactPluginVersion": 11,
    "X-KDE-Weight": 200
}

==> kmail_22.12.3.orig.tar.xz: kmail-22.12.3/src/kontactplugin/kmail/kmailplugin.json.cmake <==
{
    "KPlugin": {
        "Description": "Kontact KMail Plugin",
        "Description[ar]": "ملحقة «بريدك» لِ‍«متراسلك»",
        "Description[az]": "Kontact KMail plaqini",
        "Description[bg]": "Приставка за контакти на KMail",
        "Description[ca@valencia]": "Connector de KMail de Kontact",
        "Description[ca]": "Connector del KMail del Kontact",
        "Description[cs]": "Modul KMailu pro aplikaci Kontact",
        "Description[de]": "KMail-Modul für Kontact",
        "Description[en_GB]": "Kontact KMail Plugin",
        "Description[es]": "Complemento de KMail para Kontact",
        "Description[eu]": "Kontact-erako KMail-en plugina",
        "Description[fi]": "Kontactin KMail-liitännäinen",
        "Description[fr]": "Module externe « KMail » pour Kontact",
        "Description[ia]": "Plug-in pro Kontact KMail",
        "Description[id]": "Plugin Kontact KMail",
        "Description[it]": "Estensione per Kontact di KMail",
        "Description[ka]": "Kontact-ის დამატება KMail -სთვის",
        "Description[ko]": "Kontact KMail 플러그인",
        "Description[nl]": "Kontact KMail-plug-in",
        "Description[pl]": "Wtyczka Kontact do współpracy z KMail",
        "Description[pt]": "'Plugin' do KMail para o Kontact",
        "Description[pt_BR]": "Plugin do KMail para o Kontact",
        "Description[ru]": "Почта",
        "Description[sl]": "Vstavek Kontact za KMail",
        "Description[sv]": "Kontact-insticksprogram för Kmail",
        "Description[ta]": "காண்டாக்டுக்கான கேமெயில் செருகுநிரல்",
        "Description[tr]": "Kontak K Posta Eklentisi",
        "Description[uk]": "Додаток електронної пошти Kontact",
        "Description[x-test]": "xxKontact KMail Pluginxx",
        "Description[zh_CN]": "Kontact KMail 插件",
        "EnabledByDefault": true,
        "Icon": "view-pim-mail",
        "Id": "kontact_kmailplugin",
        "License": "GPL",
        "Name": "Mail",
        "Name[af]": "Pos",
        "Name[ar]": "البريد",
        "Name[az]": "Poçt",
        "Name[be]": "Пошта",
        "Name[bg]": "Mail",
        "Name[br]": "Lizher",
        "Name[bs]": "Elektronska pošta",
        "Name[ca@valencia]": "Correu",
        "Name[ca]": "Correu",
        "Name[cs]": "Pošta",
        "Name[cy]": "Ebost",
        "Name[da]": "E-mail",
        "Name[de]": "E-Mail",
        "Name[el]": "Αλληλογραφία",
        "Name[en_GB]": "Mail",
        "Name[eo]": "Retpoŝto",
        "Name[es]": "Correo",
        "Name[et]": "E-post",
        "Name[eu]": "Posta",
        "Name[fa]": "نامه",
        "Name[fi]": "Sähköposti",
        "Name[fr]": "Messages",
        "Name[fy]": "E-post",
        "Name[ga]": "Ríomhphost",
        "Name[gl]": "Correo electrónico",
        "Name[he]": "דוא\"ל",
        "Name[hr]": "Pošta",
        "Name[hu]": "E-mail",
        "Name[ia]": "Posta",
        "Name[id]": "Mail",
        "Name[is]": "Póstur",
        "Name[it]": "Posta",
        "Name[ja]": "メール",
        "Name[ka]": "წერილი",
        "Name[kk]": "Пошта",
        "Name[km]": "សំបុត្រ",
        "Name[ko]": "이메일",
        "Name[lt]": "Paštas",
        "Name[lv]": "Pasts",
        "Name[mai]": "डाक",
        "Name[mk]": "Е-пошта",
        "Name[mr]": "मेल",
        "Name[ms]": "Mel",
        "Name[nb]": "E-post",
        "Name[nds]": "Nettpost",
        "Name[ne]": "पत्र",
        "Name[nl]": "E-mail",
        "Name[nn]": "E-post",
        "Name[pa]": "ਮੇਲ",
        "Name[pl]": "Poczta",
        "Name[pt]": "E-mail",
        "Name[pt_BR]": "E-mail",
        "Name[ro]": "Poștă",
        "Name[ru]": "Почта",
        "Name[se]": "E-boasta",
        "Name[sk]": "Pošta",
        "Name[sl]": "Pošta",
        "Name[sr@ijekavian]": "Пошта",
        "Name[sr@ijekavianlatin]": "Pošta",
        "Name[sr@latin]": "Pošta",
        "Name[sr]": "Пошта",
        "Name[sv]": "Brev",
        "Name[ta]": "அஞ்சல்",
        "Name[tg]": "Мактуб",
        "Name[th]": "จดหมาย",
        "Name[tr]": "E-Posta",
        "Name[ug]": "خەت",
        "Name[uk]": "Пошта",
        "Name[uz@cyrillic]": "Хат-хабар",
        "Name[uz]": "Xat-xabar",
        "Name[wa]": "Emile",
        "Name[x-test]": "xxMailxx",
        "Name[zh_CN]": "邮寄",
        "Name[zh_TW]": "郵件",
        "Version": "0.1",
        "Website": "https://kontact.kde.org/components/kmail/"
    },
    "X-KDE-ConfigModuleNamespace": "pim@QT_MAJOR_VERSION@/kcms/kmail/",
    "X-KDE-KontactPartExecutableName": "kmail",
    "X-KDE-KontactPartLibraryName": "kmailpart",
    "X-KDE-KontactPartLoadOnStart": true,
    "X-KDE-KontactPluginHasSummary": true,
    "X-KDE-KontactPluginVersion": 11,
    "X-KDE-Weight": 200
}
